@@ -1,26 +1,27 @@
+use posish::io::Errno;
 use std::io;
 
 #[cold]
 pub(crate) fn invalid_flags() -> io::Error {
-    io::Error::from_raw_os_error(libc::EINVAL)
+    Errno::INVAL.io_error()
 }
 
 #[cold]
 pub(crate) fn no_such_file_or_directory() -> io::Error {
-    io::Error::from_raw_os_error(libc::ENOENT)
+    Errno::NOENT.io_error()
 }
 
 #[cold]
 pub(crate) fn is_directory() -> io::Error {
-    io::Error::from_raw_os_error(libc::EISDIR)
+    Errno::ISDIR.io_error()
 }
 
 #[cold]
 pub(crate) fn is_not_directory() -> io::Error {
-    io::Error::from_raw_os_error(libc::ENOTDIR)
+    Errno::NOTDIR.io_error()
 }
 
 #[cold]
 pub(crate) fn too_many_symlinks() -> io::Error {
-    io::Error::from_raw_os_error(libc::ELOOP)
+    Errno::LOOP.io_error()
 }
