@@ -1,4 +1,5 @@
 use crate::fs::{manually, open_beneath, OpenOptions};
+use posish::io::Errno;
 use std::{ffi::OsStr, fs, io};
 
 pub(crate) fn open_entry_impl(
@@ -10,8 +11,8 @@ pub(crate) fn open_entry_impl(
 
     match result {
         Ok(file) => Ok(file),
-        Err(err) => match err.raw_os_error() {
-            Some(libc::ENOSYS) => manually::open_entry(start, path, options),
+        Err(err) => match Errno::from_io_error(&err) {
+            Some(Errno::NOSYS) => manually::open_entry(start, path, options),
             _ => Err(err),
         },
     }
