@@ -4,6 +4,7 @@
 use super::procfs::set_times_through_proc_self_fd;
 use crate::fs::{open, OpenOptions, SystemTimeSpec};
 use fs_set_times::SetTimes;
+use posish::io::Errno;
 use std::{fs, io, path::Path};
 
 pub(crate) fn set_times_impl(
@@ -21,8 +22,8 @@ pub(crate) fn set_times_impl(
                 mtime.map(SystemTimeSpec::into_std),
             )
         }
-        Err(err) => match err.raw_os_error() {
-            Some(libc::EACCES) | Some(libc::EISDIR) => (),
+        Err(err) => match Errno::from_io_error(&err) {
+            Some(Errno::ACCES) | Some(Errno::ISDIR) => (),
             _ => return Err(err),
         },
     }
@@ -35,8 +36,8 @@ pub(crate) fn set_times_impl(
                 mtime.map(SystemTimeSpec::into_std),
             )
         }
-        Err(err) => match err.raw_os_error() {
-            Some(libc::EACCES) => (),
+        Err(err) => match Errno::from_io_error(&err) {
+            Some(Errno::ACCES) => (),
             _ => return Err(err),
         },
     }
